@@ -1,22 +1,5 @@
 package Text::Similarity::Overlaps;
 
-# Text::Similarity::Overlaps
-# Copyright (C) 2004, Jason Michelizzi and Ted Pedersen
-
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
 use 5.006;
 use strict;
 use warnings;
@@ -26,7 +9,6 @@ use Text::OverlapFinder;
 
 our @ISA = qw(Text::Similarity);
 
-
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
@@ -34,20 +16,18 @@ our @ISA = qw(Text::Similarity);
 # This allows declaration	use Text::Similarity::Overlaps ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 
+our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-use constant {
-    WORD      => 0,
-    SENTENCE  => 1,
-    PARAGRAPH => 2,
-    DOCUMENT  => 3
-};
+use constant WORD      => 0;
+use constant SENTENCE  => 1;
+use constant PARAGRAPH => 2;
+use constant DOCUMENT  => 3;
 
 my %finder;
 
@@ -139,6 +119,16 @@ sub getSimilarity
 	$score += scalar @words * $overlaps->{$key};
     }
 
+    # fix for divide by zero error, will short circuit when score is 0
+    # provided by cernst at esoft.com
+    # who reported via rt.cpan.org ticket 29902
+
+    if ($score == 0){
+	return $score;
+	}
+
+    # end of fix
+
     if ($self->normalize) {
 	if ($self->verbose) {
 	    print "wc 1: $wc1\n";
@@ -170,7 +160,6 @@ sub doStop {0}
 
 __END__
 
-
 =head1 NAME
 
 Text::Similarity::Overlaps - module for computing the similarity of text
@@ -178,31 +167,60 @@ documents using literal string (word token) overlaps
 
 =head1 SYNOPSIS
 
+  # this will return an un-normalized score that just gives the
+  # number of overlaps
+
   use Text::Similarity::Overlaps;
-  my $module = Text::Similarity::Overlaps->new;
-  my $score = $module->getSimilarity ($file1, $file2);
+  my $mod = Text::Similarity::Overlaps->new;
+  defined $mod or die "Construction of Text::Similarity::Overlaps failed";
+
+  # adjust file names to reflect true relative position
+  # these paths are valid from lib/Text/Similarity
+  my $text_file1 = '../../../t/test1.txt';
+  my $text_file2 = '../../../t/test2.txt';
+
+  my $score = $mod->getSimilarity ($text_file1, $text_file2);
+  print "The similarity of $text_file1 and $text_file2 is : $score\n";
 
 =head1 DESCRIPTION
 
 This module computes the similarity of two text documents by searching
 for literal word token overlaps in the two documents.  The score is based
-on the F-measure and ranges between 0 and 1.
+on the F-measure and ranges between 0 and 1. The F-measure is defined as 
+follows :
+
+ precision = overlap_score / length_of_file_2
+ recall    = overlap_score / length_of_file_1
+ F-measure = 2 * precision * recall / (precision + recall)
 
 =head1 SEE ALSO
 
-Text::Similarity, Text::OverlapFinder, text_compare.pl
-
 =head1 AUTHOR
 
-Jason Michelizzi, E<lt>jmichelizzi at sourceforge.netE<gt>
+Ted Pedersen, University of Minnesota, Duluth
+tpederse at d.umn.edu
 
-Ted Pedersen, E<lt>tpederse at d.umn.eduE<gt>
+Jason Michelizzi
+
+Last modified by : 
+$Id: Overlaps.pm,v 1.11 2008/03/20 04:40:46 tpederse Exp $
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004 by Jason Michelizzi and Ted Pedersen
+Copyright (C) 2004-2008 by Jason Michelizzi and Ted Pedersen
 
-This library is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License.
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 =cut
